@@ -283,7 +283,33 @@ class UserMixin:
             self._users_cache[user_id]
         )  # return copy of cache (dict changes protection)
 
+    def new_feed_exist(self) -> bool:
+        """
+        Returns bool
+        -------
+        Check if new feed exist
+        -------
+        True if new feed exist ,
+        After Login or load Settings always return False
+        """
+        results = self.private_request("feed/new_feed_posts_exist/")
+        return results.get("new_feed_posts_exist", False)
+
     def user_friendship_v1(self, user_id: int) -> Relationship:
+        """
+        Get user friendship status
+
+        Parameters
+        ----------
+        user_id: int
+            User id of an instagram account
+
+        Returns
+        -------
+        Relationship
+            An object of Relationship type
+        """
+
         try:
             results = self.private_request(f"friendships/show/{user_id}/")
             return Relationship(**results)
@@ -293,19 +319,19 @@ class UserMixin:
 
     def search_followers_v1(self, user_id: int, query: str) -> List[UserShort]:
         """
-        Search by followers (Private Mobile API)
+        Search users by followers (Private Mobile API)
 
         Parameters
         ----------
         user_id: int
             User id of an instagram account
         query: str
-            Query string
+            Query to search
 
         Returns
         -------
         List[UserShort]
-            List of User short object
+            List of users
         """
         results = self.private_request(
             f"friendships/{user_id}/followers/",
@@ -338,19 +364,19 @@ class UserMixin:
 
     def search_following_v1(self, user_id: int, query: str) -> List[UserShort]:
         """
-        Search by following (Private Mobile API)
+        Search following users (Private Mobile API)
 
         Parameters
         ----------
         user_id: int
             User id of an instagram account
         query: str
-            Query string
+            Query to search
 
         Returns
         -------
         List[UserShort]
-            List of User short object
+            List of users
         """
         results = self.private_request(
             f"friendships/{user_id}/following/",
